package com.ruoyi.abuwx.mapper;

import com.ruoyi.abuwx.domain.UserFeedback;

import java.util.List;

/**
 * 用户反馈管理Mapper接口
 * 
 * @author lujie
 * @date 2025-01-20
 */
public interface UserFeedbackMapper 
{
    /**
     * 查询用户反馈管理
     * 
     * @param id 用户反馈管理主键
     * @return 用户反馈管理
     */
    public UserFeedback selectUserFeedbackById(Long id);

    /**
     * 查询用户反馈管理列表
     * 
     * @param userFeedback 用户反馈管理
     * @return 用户反馈管理集合
     */
    public List<UserFeedback> selectUserFeedbackList(UserFeedback userFeedback);

    /**
     * 新增用户反馈管理
     * 
     * @param userFeedback 用户反馈管理
     * @return 结果
     */
    public int insertUserFeedback(UserFeedback userFeedback);

    /**
     * 修改用户反馈管理
     * 
     * @param userFeedback 用户反馈管理
     * @return 结果
     */
    public int updateUserFeedback(UserFeedback userFeedback);

    /**
     * 删除用户反馈管理
     * 
     * @param id 用户反馈管理主键
     * @return 结果
     */
    public int deleteUserFeedbackById(Long id);

    /**
     * 批量删除用户反馈管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUserFeedbackByIds(Long[] ids);
}
